from gxdltk.th.header import *
def sim(a: tensor, b: tensor) -> float:
    """
    calc vector sim
    :param a:
    :param b:
    :return:
    """
    res = th.dot(a, b) / (a.norm() * b.norm())
    return res.item()



from gxdltk.th.header import *


def batch_provider(*data: list, batch_size: int = 1, shuffle: bool = True) \
        -> \
                tdata.DataLoader:
    """
    convert list type data to a dataloader
    :param data: your data, tensor
    :return: data loader
    """
    dtensors = tuple(map(tensor, data))  # tensor tuple
    dataset = tdata.TensorDataset(*dtensors)
    loader = tdata.DataLoader(dataset=dataset, batch_size=batch_size,
                              shuffle=shuffle)
    return loader



from gxdltk.header import *

def calc_acc(pred: list, label: list) -> float:
    """
    calc accuracy
    :param pred:
    :param label:
    :return:
    """
    assert len(pred) == len(label), "length of arg#1 must be equal to arg#2"
    p = np.array(pred)
    l = np.array(label)
    return np.sum(p == l) / len(label)



from gxdltk.mx.header import *

__all__ = ['batch_provider']

def batch_provider(*data: list, batch_size: int = 1,
                      shuffle: bool = True) -> gdata.DataLoader:
    """
    provide batch data
    :param data: RAW data, list type
    :param batch_size: batch size
    :param shuffle:
    :return: gluon.dataloader
    """
    dataset = gdata.ArrayDataset(data)
    data_iter = gdata.DataLoader(dataset, batch_size, shuffle=shuffle)
    return data_iter



from setuptools import setup
import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()
setup(
        name='gxdltk', # package name
        version='0.3-beta-2', # version
        description="DeepLearning Toolkit for pytorch",
        author='gawainx',
        author_email='liangyixp@live.cn',
        install_requires=['numpy', 'torch','mxnet'],
        long_description=long_description,
        long_description_content_type="text/markdown",
        classifiers=[
            "Programming Language :: Python :: 3.7",
            "License :: OSI Approved :: MIT License",
            "Operating System :: OS Independent",
        ],
        packages=setuptools.find_packages(),
)



from gxdltk.mx.header import *

__all__ = ['array','sim']

def array(data: list, ctx: mx.Context=mx.cpu()) -> NDArray:
    """
    Convert list data into ndarray
    :param data:
    :param ctx: context, default mx.cpu()
    :return:
    """
    return nd.array(data).as_in_context(ctx)

def sim(a : NDArray, b: NDArray)-> float:
    """
    calc vector sim in mxnet
    :param a: vec a
    :param b: vec b
    :return: similarity of a and b
    """
    res = nd.dot((a, b)) / (a.norm() * b.norm())
    return res



from mxnet import gluon
import mxnet as mx



def trainer(params: gluon.ParameterDict, optim: str = 'sgd', learning_rate=1e-2,
            weight_decay=0):
    """
    Provide gluon trainer
    :return:
    """
    return gluon.Trainer(params, optim,
                         {'learning_rate': learning_rate,
                          'wd':            weight_decay})


def softmaxCELoss(ctx: mx.Context, from_logits=False):
    """
    Provide wrap Softmax CELoss
    :return: Initialized gluon.loss.SoftmaxCELoss layer
    """
    loss_fcn = gluon.loss.SoftmaxCELoss(from_logits)
    loss_fcn.initialize(ctx=ctx)
    return loss_fcn
